@@ -306,7 +306,10 @@ def waitfor(proc, timeout_in_s: float = -1,
     exit_code = proc.poll()
     if discard_output:
         out, err = proc.communicate()
+        warning_message = 'process: {}\nexited with error: {}\nand output: {}'.format(
+            ' '.join([str(arg) for arg in proc.args]), err, out)
+    else:
+        warning_message = 'process: {}\nexited with error.'.format(' '.join([str(arg) for arg in proc.args]))
     if exit_code > 0:
-        warnings.warn(
-            'process: {}\nexited with error: {}\nand output: {}'.format(' '.join([str(arg) for arg in proc.args]), err, out))
+        warnings.warn(warning_message)
     return proc.poll()
